import java.awt.*; import javax.swing.*; import java.io.*;
/*
	WalkMap.java 
	(c)1999-2003 SSC Development Team
	Function: Managing the area data structure
	Allowed Dependencies: Tileset.java, Tile.java	
*/

public class WalkMap implements Serializable
{
//Tileset data structure containing the actual tile data 
private Tileset tileset;	
public Tileset getTileset() { return tileset; }
public void setTileset(Tileset t) { this.tileset = t; } 

//The grid which holds the tile values for every map square.
private int[][][] tiles;
public int[][][] getTiles() { return tiles; }
public void setTiles(int[][][] t) { this.tiles = t;  }

//Map width/height in tiles.
private int width, height;
public int getHeight() { return height; }
public int getWidth() { return width; }

//References to the corresponding Script and EntityFile
private String Scriptfile, Entityfile;
public String getScriptfile() { return this.Scriptfile; }
public String getEntityfile() { return this.Entityfile; }
public void setScriptfile(String scr) { this.Scriptfile = scr; }
public void setEntityfile(String ent) { this.Entityfile = ent; }


public WalkMap() {
	
	}
	
public WalkMap(Tileset tileset, int width, int height) { //Constructor
	this.tiles = new int[width][height][6];
	this.tileset = tileset;
	this.width = width;		//width in tiles
	this.height = height;	//height in tiles
	
	for(int i=0;i<width;i++) {
		for(int j=0;j<height;j++) {
			tiles[i][j][0] = 1; //First layer
			tiles[i][j][1] = 0; //Second Layer
			tiles[i][j][2] = 0; //Third Layer
			tiles[i][j][3] = 0; //Obstruction/Land Effect Layer
			tiles[i][j][4] = 0; //Event Layer
			tiles[i][j][5] = 0; //Entity Layer
			}
		}
	}

public Image getBlock(int x, int y, int layer) { //returns value of target Block on base layer. 
	return tileset.getTileContents(tiles[x][y][layer]);
	}

public int getValue(int x, int y, int layer) {
	if(x >= 0 && y >= 0 && x<width && y<height) { return tiles[x][y][layer]; }
	return -1; //error output
	}
	
public void setBlock(int x, int y, int layer, int value) { //sets value of target block.
	if(x >= 0 && y >= 0 && x<width && y<height) {
		tiles[x][y][layer] = value;
		}
	}	

public void updateMap() { 
//Updates the map animation
	for(int i=0;i<width;i++) {
	for(int j=0;j<height;j++) {
			int next0 = tileset.getTile(this.getValue(i,j,0)).getNextTile();
			int next1 = tileset.getTile(this.getValue(i,j,1)).getNextTile();
			int next2 = tileset.getTile(this.getValue(i,j,2)).getNextTile();
			if(next0 > 0) { tiles[i][j][0] = next0; }
			if(next1 > 0) { tiles[i][j][1] = next1; }
			if(next2 > 0) { tiles[i][j][2] = next2; }
			}
		}
	
	}
	
public void resize(int w, int h) {		
	int[][][] temp = this.tiles;
	this.tiles = new int[w][h][3];
	
	for(int i=0;i<w && i<width;i++) {
	for(int j=0;j<h && j<height;j++) {
		tiles[i][j][0] = temp[i][j][0];
		tiles[i][j][1] = temp[i][j][1];
		tiles[i][j][2] = temp[i][j][2];
		}
	}
	
	this.width = w;
	this.height = h;
	}
}